@@ -36,6 +36,7 @@
 #include <errno.h>
 #include <signal.h>
 #include <stdlib.h>
+#include <string.h>
 #include <syslog.h>
 #include <unistd.h>
 
@@ -546,7 +547,8 @@ get_routes(const struct interface *iface)
 		return nrt;
 	}
 
-	return get_option_routes(iface->state->new);
+	return get_option_routes(iface->state->new,
+	    iface->name, &iface->state->options->options);
 }
 
 static struct rt *
@@ -654,10 +656,12 @@ configure(struct interface *iface)
 	sort_interfaces();
 
 	if (dhcp == NULL) {
-		build_routes();
-		if (iface->addr.s_addr != 0)
-			delete_address(iface);
-		run_script(iface);
+		if (!(ifo->options & DHCPCD_PERSISTENT)) {
+			build_routes();
+			if (iface->addr.s_addr != 0)
+				delete_address(iface);
+			run_script(iface);
+		}
 		return 0;
 	}
 
