@@ -79,6 +79,13 @@ if_init(_unused struct interface *iface)
 	return 0;
 }
 
+int
+if_conf(_unused struct interface *iface)
+{
+	/* No extra checks needed on BSD */
+	return 0;
+}
+
 int
 init_sockets(void)
 {
